==> openturns_1.5.orig.tar.bz2: openturns-1.5/lib/src/Base/Common/LessOrEqual.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  LessOrEqual.cxx
 *  @brief Abstract top-level class for all LessOrEqual
 *
 *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "LessOrEqual.hxx"
#include "PersistentObjectFactory.hxx"

BEGIN_NAMESPACE_OPENTURNS

CLASSNAMEINIT(LessOrEqual);

static Factory<LessOrEqual> RegisteredFactory("LessOrEqual");

/* Default constructor */
LessOrEqual::LessOrEqual()
  : ComparisonOperatorImplementation()
{
  // Nothing to do
}

/* String converter */
String LessOrEqual::__repr__() const
{
  return OSS() << "class=" << LessOrEqual::GetClassName()
         << " name=" << getName();
}


/* Here is the interface that all derived class must implement */

/* Virtual constructor */
LessOrEqual * LessOrEqual::clone() const
{
  return new LessOrEqual(*this);
}

/* Return true if comparison succeeds */
Bool LessOrEqual::operator() (const NumericalScalar a,
                              const NumericalScalar b) const
{
  return (a <= b);
}

/* Method save() stores the object through the StorageManager */
void LessOrEqual::save(Advocate & adv) const
{
  ComparisonOperatorImplementation::save(adv);
}


/* Method load() reloads the object from the StorageManager */
void LessOrEqual::load(Advocate & adv)
{
  ComparisonOperatorImplementation::load(adv);
}





END_NAMESPACE_OPENTURNS

==> openturns_1.10~rc1.orig.tar.bz2: openturns-1.10rc1/lib/src/Base/Common/LessOrEqual.cxx <==
//                                               -*- C++ -*-
/**
 *  @brief Abstract top-level class for all LessOrEqual
 *
 *  Copyright 2005-2017 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#include "openturns/LessOrEqual.hxx"
#include "openturns/PersistentObjectFactory.hxx"

BEGIN_NAMESPACE_OPENTURNS

CLASSNAMEINIT(LessOrEqual)

static const Factory<LessOrEqual> Factory_LessOrEqual;

/* Default constructor */
LessOrEqual::LessOrEqual()
  : ComparisonOperatorImplementation()
{
  // Nothing to do
}

/* String converter */
String LessOrEqual::__repr__() const
{
  return OSS() << "class=" << LessOrEqual::GetClassName()
         << " name=" << getName();
}


/* Here is the interface that all derived class must implement */

/* Virtual constructor */
LessOrEqual * LessOrEqual::clone() const
{
  return new LessOrEqual(*this);
}

/* Return true if comparison succeeds */
Bool LessOrEqual::operator() (const Scalar a,
                              const Scalar b) const
{
  return (a <= b);
}

/* Method save() stores the object through the StorageManager */
void LessOrEqual::save(Advocate & adv) const
{
  ComparisonOperatorImplementation::save(adv);
}


/* Method load() reloads the object from the StorageManager */
void LessOrEqual::load(Advocate & adv)
{
  ComparisonOperatorImplementation::load(adv);
}





END_NAMESPACE_OPENTURNS
